@@ -1,7 +1,7 @@
 /*===========================================================================*\
  *                                                                           *
  *                               OpenMesh                                    *
- *      Copyright (C) 2001-2012 by Computer Graphics Group, RWTH Aachen      *
+ *      Copyright (C) 2001-2014 by Computer Graphics Group, RWTH Aachen      *
  *                           www.openmesh.org                                *
  *                                                                           *
  *---------------------------------------------------------------------------* 
@@ -34,8 +34,8 @@
 
 /*===========================================================================*\
  *                                                                           *             
- *   $Revision: 736 $                                                         *
- *   $Date: 2012-10-08 09:30:49 +0200 (Mo, 08. Okt 2012) $                   *
+ *   $Revision: 990 $                                                         *
+ *   $Date: 2014-02-05 10:01:07 +0100 (Mi, 05 Feb 2014) $                   *
  *                                                                           *
 \*===========================================================================*/
 
@@ -380,18 +380,18 @@ get_active_cuts(const VHierarchyNodeHandle _node_handle, MyMesh::VertexHandle &v
   
   for (vv_it=mesh_.vv_iter(vhierarchy_.vertex_handle(_node_handle)); vv_it; ++vv_it)
 	{
-    nnode_handle = mesh_.data(vv_it.handle()).vhierarchy_node_handle();
+    nnode_handle = mesh_.data(*vv_it).vhierarchy_node_handle();
     nnode_index = vhierarchy_.node_index(nnode_handle);
 
     if (vl == MyMesh::InvalidVertexHandle && vhierarchy_.is_ancestor(nnode_index, fund_lcut_index) == true)
-      vl = vv_it.handle();
+      vl = *vv_it;
     if (vr == MyMesh::InvalidVertexHandle && vhierarchy_.is_ancestor(nnode_index, fund_rcut_index) == true)
-      vr = vv_it.handle();
+      vr = *vv_it;
 
     /*if (vl == MyMesh::InvalidVertexHandle && nnode_index.is_ancestor_index(fund_lcut_index) == true)
-      vl = vv_it.handle();
+      vl = *vv_it;
     if (vr == MyMesh::InvalidVertexHandle && nnode_index.is_ancestor_index(fund_rcut_index) == true)
-      vr = vv_it.handle();*/
+      vr = *vv_it;*/
 
     if (vl != MyMesh::InvalidVertexHandle && vr != MyMesh::InvalidVertexHandle)
       break;
